@@ -7,27 +7,27 @@ execute_system_command(const char *cmd)
 	// https://stackoverflow.com/questions/18678943/ncurses-shell-escape-drops-parent-process-output
 	info_status("Executing %s", cmd);
 	pthread_mutex_lock(&interface_lock);
-	curs_set(1); // Some programs expect that the cursor is enabled.
-	reset_shell_mode();
+	NEWSRAFT_CURSES(curs_set(1)); // Some programs expect that the cursor is enabled.
+	NEWSRAFT_CURSES(reset_shell_mode());
 	int status = system(cmd);
 	fflush(stdout);
-	reset_prog_mode();
-	curs_set(0);
+	fflush(stderr);
+	NEWSRAFT_CURSES(reset_prog_mode());
+	NEWSRAFT_CURSES(curs_set(0));
 	pthread_mutex_unlock(&interface_lock);
 	// Resizing could be handled by the program running on top, so we have to catch up.
-	if (call_resize_handler_if_current_list_menu_size_is_different_from_actual() == false) {
+	if (curses_is_running() && call_resize_handler_if_current_list_menu_size_is_different_from_actual() == false) {
 		pthread_mutex_lock(&interface_lock);
 		clear();
 		refresh();
 		status_recreate_unprotected();
-		counter_recreate_unprotected();
 		redraw_list_menu_unprotected();
 		pthread_mutex_unlock(&interface_lock);
 	}
 	if (status == 0) {
 		status_clean();
 	} else {
-		fail_status("Failed to execute %s", cmd);
+		fail_status("Failed with status %d to run %s", status, cmd);
 	}
 }
 
@@ -43,7 +43,7 @@ copy_string_to_clipboard(const struct string *src)
 		}
 		fwrite(src->ptr, sizeof(char), src->len, p);
 		pclose(p);
-		good_status("Copied %s", src->ptr);
+		info_status("Copied %s", src->ptr);
 	}
 }
 
