@@ -37,32 +37,76 @@ convert_seconds_to_human_readable_duration_string(char *dest, size_t dest_size,
 	return snprintf(dest, dest_size, "%.1f hours", duration / 3600);
 }
 
-// Return codes correspond to:
-// [0; INT64_MAX] link was added successfully with that index
-// {-1}           memory failure
-int64_t
-add_another_url_to_trim_links_list(struct links_list *links, const char *url, size_t url_len)
+// See tests/complete_url.c to understand what it takes in and spews out.
+char *
+complete_url(const char *base, const char *rel)
 {
-	for (int64_t i = 0; i < (int64_t)links->len; ++i) {
-		if ((url_len == links->ptr[i].url->len) && (strncmp(url, links->ptr[i].url->ptr, url_len) == 0)) {
-			// Don't add duplicate.
-			return i;
+	if (base == NULL || rel == NULL) {
+		return NULL;
+	}
+	// Don't complete links with protocol scheme
+	// Don't complete telephone links
+	// Don't complete email links
+	if (strstr(rel, "://") != NULL || strstr(rel, "tel:") == rel || strstr(rel, "mailto:") == rel) {
+		return strdup(rel);
+	}
+	CURLU *link = curl_url();
+	if (link == NULL) {
+		return NULL;
+	}
+	if (curl_url_set(link, CURLUPART_URL, base, 0) != CURLUE_OK) {
+		curl_url_cleanup(link);
+		return NULL;
+	}
+	if (curl_url_set(link, CURLUPART_URL, rel, 0) != CURLUE_OK) {
+		curl_url_cleanup(link);
+		return NULL;
+	}
+	char *new_url = NULL;
+	if (curl_url_get(link, CURLUPART_URL, &new_url, 0) != CURLUE_OK || new_url == NULL) {
+		curl_free(new_url);
+		curl_url_cleanup(link);
+		return NULL;
+	}
+	char *complete = strdup(new_url);
+	curl_free(new_url);
+	curl_url_cleanup(link);
+	return complete;
+}
+
+// Returns link index in the links list or -1 in case of failure.
+int64_t
+add_url_to_links_list(struct links_list *links, const char *url, size_t url_len)
+{
+	char *full_url = NULL;
+	if (links->len > 0) {
+		full_url = complete_url(links->ptr[0].url->ptr, url);
+		if (full_url != NULL) {
+			url = full_url;
+			url_len = strlen(full_url);
 		}
 	}
-	struct link *temp = realloc(links->ptr, sizeof(struct link) * (links->len + 1));
-	if (temp == NULL) {
+
+	for (int64_t i = 0; i < (int64_t)links->len; ++i) {
+		if (url_len == links->ptr[i].url->len && strncmp(url, links->ptr[i].url->ptr, url_len) == 0) {
+			free(full_url);
+			return i; // Don't add duplicate.
+		}
+	}
+	struct link *tmp = realloc(links->ptr, sizeof(struct link) * (links->len + 1));
+	if (tmp == NULL) {
+		free(full_url);
 		return -1;
 	}
-	size_t index = (links->len)++;
-	links->ptr = temp;
-	links->ptr[index].url = crtas(url, url_len);
-	links->ptr[index].type = NULL;
-	links->ptr[index].size = NULL;
-	links->ptr[index].duration = NULL;
-	if (links->ptr[index].url == NULL) {
-		return -1;
-	}
-	return index;
+
+	int64_t index = (links->len)++;
+	links->ptr = tmp;
+	memset(&links->ptr[index], 0, sizeof(struct link));
+	cpyas(&links->ptr[index].url, url, url_len);
+
+	free(full_url);
+
+	return links->ptr[index].url == NULL ? -1 : index;
 }
 
 static void
@@ -74,32 +118,6 @@ free_contents_of_link(const struct link *link)
 	free_string(link->duration);
 }
 
-void
-free_links_list(const struct links_list *links)
-{
-	if (links->ptr != NULL) {
-		for (size_t i = 0; i < links->len; ++i) {
-			free_contents_of_link(&(links->ptr[i]));
-		}
-		free(links->ptr);
-	}
-}
-
-static inline bool
-append_raw_link(struct links_list *links, sqlite3_stmt *res, items_column_id column)
-{
-	const char *text = (char *)sqlite3_column_text(res, column);
-	if (text != NULL) {
-		size_t text_len = strlen(text);
-		if (text_len != 0) {
-			if (add_another_url_to_trim_links_list(links, text, text_len) < 0) {
-				return false;
-			}
-		}
-	}
-	return true; // It's not an error because this item simply doesn't have link set.
-}
-
 static inline bool
 add_another_link_to_trim_link_list(struct links_list *links, const struct link *link)
 {
@@ -128,8 +146,8 @@ add_another_link_to_trim_link_list(struct links_list *links, const struct link *
 	return true;
 }
 
-static inline bool
-append_attachments(struct links_list *links, sqlite3_stmt *res)
+bool
+add_item_attachments_to_links_list(struct links_list *links, sqlite3_stmt *res)
 {
 	const char *text = (const char *)sqlite3_column_text(res, ITEM_COLUMN_ATTACHMENTS);
 	if (text == NULL) {
@@ -173,17 +191,6 @@ error:
 	return false;
 }
 
-bool
-populate_link_list_with_links_of_item(struct links_list *links, sqlite3_stmt *res)
-{
-	if (append_raw_link(links, res, ITEM_COLUMN_LINK) == true) {
-		if (append_attachments(links, res) == true) {
-			return true;
-		}
-	}
-	return false;
-}
-
 struct wstring *
 generate_link_list_wstring_for_pager(struct config_context **ctx, const struct links_list *links)
 {
@@ -252,48 +259,3 @@ error:
 	free_string(str);
 	return NULL;
 }
-
-// Convert relative URLs of links to absolute form. For example:
-// (1) /upload/podcast83.mp3      => http://example.org/upload/podcast83.mp3
-// (2) ../../images/image-194.jpg => http://example.org/post13/../../images/image-194.jpg
-// (3) image-195.jpg              => http://example.org/post13/image-195.jpg
-bool
-complete_urls_of_links(struct links_list *links)
-{
-	INFO("Completing URLs of links list.");
-	CURLU *h = curl_url();
-	if (h == NULL) {
-		FAIL("Not enough memory for completing URLs of links list!");
-		return false;
-	}
-	char *url;
-	for (size_t i = 0; i < links->len; ++i) {
-		if (strncmp(links->ptr[i].url->ptr, "mailto:", 7) == 0) {
-			continue; // This is an email URL, leave it as is.
-		}
-		if (strncmp(links->ptr[i].url->ptr, "tel:", 4) == 0) {
-			continue; // This is a telephone URL, leave it as is.
-		}
-		if (strstr(links->ptr[i].url->ptr, "://") != NULL) {
-			continue; // This URL has protocol scheme, it's most likely absolute.
-		}
-		if (curl_url_set(h, CURLUPART_URL, links->ptr[0].url->ptr, 0) != CURLUE_OK) {
-			continue; // This URL is broken, leave it alone.
-		}
-		if (curl_url_set(h, CURLUPART_URL, links->ptr[i].url->ptr, 0) != CURLUE_OK) {
-			continue; // This URL is broken, leave it alone.
-		}
-		if (curl_url_get(h, CURLUPART_URL, &url, 0) != CURLUE_OK) {
-			continue; // This URL is broken, leave it alone.
-		}
-		INFO("Completed \"%s\" to \"%s\".", links->ptr[i].url->ptr, url);
-		if (cpyas(&links->ptr[i].url, url, strlen(url)) == false) {
-			curl_free(url);
-			curl_url_cleanup(h);
-			return false;
-		}
-		curl_free(url);
-	}
-	curl_url_cleanup(h);
-	return true;
-}
