@@ -1,5 +1,4 @@
 #include <string.h>
-#include <strings.h>
 #include "load_config/load_config.h"
 
 static inline void
@@ -108,13 +107,7 @@ process_config_line(struct feed_entry *feed, const char *str, size_t len)
 			// bind/unbind <key>
 
 			extract_token_from_line(line, token, true);
-			if (strcasecmp(token->ptr, "space") == 0) {
-				bind = create_or_clean_bind(binds, " ");
-			} else if (strcasecmp(token->ptr, "tab") == 0) {
-				bind = create_or_clean_bind(binds, "^I");
-			} else {
-				bind = create_or_clean_bind(binds, token->ptr);
-			}
+			bind = create_or_clean_bind(binds, token->ptr);
 			continue;
 
 		} else if (find_config_entry_by_name(token->ptr) != CFG_ENTRIES_COUNT) {
@@ -162,6 +155,7 @@ parse_config_file(void)
 {
 	const char *config_path = get_config_path();
 	if (config_path == NULL) {
+		log_config_settings();
 		return true; // Since a config file is optional, don't return the error.
 	}
 	FILE *f = fopen(config_path, "r");
@@ -180,5 +174,6 @@ parse_config_file(void)
 	}
 	free(line);
 	fclose(f);
+	log_config_settings();
 	return true;
 }
