@@ -3,7 +3,7 @@
 #include <yajl/yajl_version.h>
 #include "newsraft.h"
 
-FILE *log_stream = NULL;
+static FILE *log_stream = NULL;
 
 bool
 log_init(const char *path)
@@ -27,6 +27,34 @@ log_init(const char *path)
 	return true;
 }
 
+void
+log_write(const char *prefix, const char *format, ...)
+{
+	if (log_stream != NULL) {
+		struct timespec t = {0};
+		clock_gettime(CLOCK_REALTIME, &t);
+		va_list args;
+		va_start(args, format);
+		fprintf(log_stream, "%02d:%02d:%02d.%03d [%s] ",
+			(int)(t.tv_sec / 3600),
+			(int)(t.tv_sec / 60 % 60),
+			(int)(t.tv_sec % 60),
+			(int)(t.tv_nsec / 1000000),
+			prefix
+		);
+		vfprintf(log_stream, format, args);
+		fputc('\n', log_stream);
+		fflush(log_stream);
+		va_end(args);
+	}
+}
+
+FILE *
+log_get_stream(void)
+{
+	return log_stream;
+}
+
 void
 log_stop(int error_code)
 {
