@@ -11,6 +11,8 @@ static struct sorting_bundle sorting_methods[] = {
 	[SORT_BY_ORIGINAL_DESC]  = {"original-desc",  "Sorted %s according to original order (descending)"},
 	[SORT_BY_TIME_ASC]       = {"time-asc",       "Sorted %s by time (ascending)"},
 	[SORT_BY_TIME_DESC]      = {"time-desc",      "Sorted %s by time (descending)"},
+	[SORT_BY_ROWID_ASC]      = {"rowid-asc",      "Sorted %s by rowid (ascending)"},
+	[SORT_BY_ROWID_DESC]     = {"rowid-desc",     "Sorted %s by rowid (descending)"},
 	[SORT_BY_UNREAD_ASC]     = {"unread-asc",     "Sorted %s by unread (ascending)"},
 	[SORT_BY_UNREAD_DESC]    = {"unread-desc",    "Sorted %s by unread (descending)"},
 	[SORT_BY_ALPHABET_ASC]   = {"alphabet-asc",   "Sorted %s in alphabetical order (ascending)"},
